@@ -1,41 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2022 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of Qt for Python.
-**
-** $QT_BEGIN_LICENSE:LGPL$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU Lesser General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU Lesser
-** General Public License version 3 as published by the Free Software
-** Foundation and appearing in the file LICENSE.LGPL3 included in the
-** packaging of this file. Please review the following information to
-** ensure the GNU Lesser General Public License version 3 requirements
-** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 2.0 or (at your option) the GNU General
-** Public license version 3 or any later version approved by the KDE Free
-** Qt Foundation. The licenses are as published by the Free Software
-** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-2.0.html and
-** https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2022 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
 
 #ifndef SBK_QTMULTIMEDIA_PYTHON_H
@@ -52,51 +16,31 @@
 #include <pyside6_qtnetwork_python.h>
 
 // Bound library includes
-#include <QtMultimedia/qmediaformat.h>
-#include <QtMultimedia/qvideoframeformat.h>
-#include <QtMultimedia/qaudioinput.h>
-#include <QtMultimedia/qaudiobuffer.h>
-#include <QtMultimedia/qaudiooutput.h>
-#include <QtMultimedia/qimagecapture.h>
-#include <QtMultimedia/qmediacapturesession.h>
-#include <QtMultimedia/qaudiosource.h>
-#include <QtMultimedia/qmediadevices.h>
-#include <QtMultimedia/qaudioformat.h>
-#include <QtMultimedia/qmediaplayer.h>
-#include <QtMultimedia/qvideosink.h>
 #include <QtMultimedia/qaudio.h>
-#include <QtMultimedia/qsoundeffect.h>
-#include <QtMultimedia/qcameradevice.h>
-#include <QtMultimedia/qcamera.h>
-#include <QtMultimedia/qaudiodevice.h>
-#include <QtMultimedia/qmediatimerange.h>
-#include <QtMultimedia/qmediametadata.h>
-#include <QtMultimedia/qvideoframe.h>
 #include <QtMultimedia/qaudiodecoder.h>
+#include <QtMultimedia/qaudiodevice.h>
+#include <QtMultimedia/qaudioformat.h>
+#include <QtMultimedia/qcamera.h>
+#include <QtMultimedia/qcameradevice.h>
+#include <QtMultimedia/qimagecapture.h>
+#include <QtMultimedia/qmediaformat.h>
+#include <QtMultimedia/qmediametadata.h>
+#include <QtMultimedia/qmediaplayer.h>
 #include <QtMultimedia/qmediarecorder.h>
-#include <QtMultimedia/qaudiosink.h>
-// Conversion Includes - Primitive Types
-#include <QAnyStringView>
-#include <QString>
-#include <QStringList>
-#include <QStringView>
-
-// Conversion Includes - Container Types
-#include <pysideqflags.h>
-#include <QList>
-#include <QMap>
-#include <pysideqflags.h>
-#include <QMultiMap>
-#include <QPair>
-#include <QQueue>
-#include <QSet>
-#include <QStack>
-#include <list>
-#include <map>
-#include <utility>
-#include <unordered_map>
-#include <vector>
-
+#include <QtMultimedia/qmediatimerange.h>
+#include <QtMultimedia/qscreencapture.h>
+#include <QtMultimedia/qsoundeffect.h>
+#include <QtMultimedia/qvideoframe.h>
+#include <QtMultimedia/qvideoframeformat.h>
+class QAudioBuffer;
+class QAudioInput;
+class QAudioOutput;
+class QAudioSink;
+class QAudioSource;
+class QCameraFormat;
+class QMediaCaptureSession;
+class QMediaDevices;
+class QVideoSink;
 // Type indices
 enum : int {
     SBK_QAUDIO_ERROR_IDX                                     = 1,
@@ -154,19 +98,24 @@ enum : int {
     SBK_QMEDIARECORDER_IDX                                   = 48,
     SBK_QMEDIATIMERANGE_IDX                                  = 53,
     SBK_QMEDIATIMERANGE_INTERVAL_IDX                         = 54,
-    SBK_QSOUNDEFFECT_LOOP_IDX                                = 56,
-    SBK_QSOUNDEFFECT_STATUS_IDX                              = 57,
-    SBK_QSOUNDEFFECT_IDX                                     = 55,
-    SBK_QVIDEOFRAME_HANDLETYPE_IDX                           = 59,
-    SBK_QVIDEOFRAME_MAPMODE_IDX                              = 60,
-    SBK_QVIDEOFRAME_ROTATIONANGLE_IDX                        = 61,
-    SBK_QVIDEOFRAME_IDX                                      = 58,
-    SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX                    = 64,
-    SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX                      = 63,
-    SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX                = 65,
-    SBK_QVIDEOFRAMEFORMAT_IDX                                = 62,
-    SBK_QVIDEOSINK_IDX                                       = 66,
-    SBK_QtMultimedia_IDX_COUNT                               = 67
+    SBK_QSCREENCAPTURE_ERROR_IDX                             = 56,
+    SBK_QSCREENCAPTURE_IDX                                   = 55,
+    SBK_QSOUNDEFFECT_LOOP_IDX                                = 58,
+    SBK_QSOUNDEFFECT_STATUS_IDX                              = 59,
+    SBK_QSOUNDEFFECT_IDX                                     = 57,
+    SBK_QVIDEOFRAME_HANDLETYPE_IDX                           = 61,
+    SBK_QVIDEOFRAME_MAPMODE_IDX                              = 62,
+    SBK_QVIDEOFRAME_ROTATIONANGLE_IDX                        = 63,
+    SBK_QVIDEOFRAME_IDX                                      = 60,
+    SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX                    = 69,
+    SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX                      = 68,
+    SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX                = 70,
+    SBK_QVIDEOFRAMEFORMAT_COLORSPACE_IDX                     = 66,
+    SBK_QVIDEOFRAMEFORMAT_COLORTRANSFER_IDX                  = 67,
+    SBK_QVIDEOFRAMEFORMAT_COLORRANGE_IDX                     = 65,
+    SBK_QVIDEOFRAMEFORMAT_IDX                                = 64,
+    SBK_QVIDEOSINK_IDX                                       = 71,
+    SBK_QtMultimedia_IDX_COUNT                               = 72
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtMultimediaTypes;
@@ -179,35 +128,35 @@ extern SbkConverter **SbkPySide6_QtMultimediaTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QTMULTIMEDIA_QLIST_INT_IDX                           = 0, // QList<int >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIATIMERANGE_INTERVAL_IDX      = 1, // QList<QMediaTimeRange::Interval >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_KEY_IDX            = 2, // QList<QMediaMetaData::Key >
-    SBK_QTMULTIMEDIA_QHASH_QMEDIAMETADATA_KEY_QVARIANT_IDX   = 3, // QHash<QMediaMetaData::Key,QVariant >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_AUDIOCODEC_IDX       = 4, // QList<QMediaFormat::AudioCodec >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_FILEFORMAT_IDX       = 5, // QList<QMediaFormat::FileFormat >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_VIDEOCODEC_IDX       = 6, // QList<QMediaFormat::VideoCodec >
-    SBK_QTMULTIMEDIA_QLIST_QSIZE_IDX                         = 7, // QList<QSize >
-    SBK_QTMULTIMEDIA_QLIST_QCAMERAFORMAT_IDX                 = 8, // QList<QCameraFormat >
-    SBK_QTMULTIMEDIA_QLIST_QAUDIOFORMAT_SAMPLEFORMAT_IDX     = 9, // QList<QAudioFormat::SampleFormat >
-    SBK_QTMULTIMEDIA_QLIST_QOBJECTPTR_IDX                    = 10, // QList<QObject* >
-    SBK_QTMULTIMEDIA_QLIST_QBYTEARRAY_IDX                    = 11, // QList<QByteArray >
-    SBK_QTMULTIMEDIA_QLIST_QAUDIODEVICE_IDX                  = 12, // QList<QAudioDevice >
-    SBK_QTMULTIMEDIA_QLIST_QCAMERADEVICE_IDX                 = 13, // QList<QCameraDevice >
-    SBK_QTMULTIMEDIA_QLIST_QIMAGECAPTURE_FILEFORMAT_IDX      = 14, // QList<QImageCapture::FileFormat >
-    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_IDX                = 15, // QList<QMediaMetaData >
-    SBK_QTMULTIMEDIA_QLIST_QVARIANT_IDX                      = 16, // QList<QVariant >
-    SBK_QTMULTIMEDIA_QLIST_QSTRING_IDX                       = 17, // QList<QString >
-    SBK_QTMULTIMEDIA_QMAP_QSTRING_QVARIANT_IDX               = 18, // QMap<QString,QVariant >
+    SBK_QTMULTIMEDIA_QLIST_INT_IDX                           = 0, // QList<int>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIATIMERANGE_INTERVAL_IDX      = 1, // QList<QMediaTimeRange::Interval>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_KEY_IDX            = 2, // QList<QMediaMetaData::Key>
+    SBK_QTMULTIMEDIA_QHASH_QMEDIAMETADATA_KEY_QVARIANT_IDX   = 3, // QHash<QMediaMetaData::Key,QVariant>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_AUDIOCODEC_IDX       = 4, // QList<QMediaFormat::AudioCodec>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_FILEFORMAT_IDX       = 5, // QList<QMediaFormat::FileFormat>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAFORMAT_VIDEOCODEC_IDX       = 6, // QList<QMediaFormat::VideoCodec>
+    SBK_QTMULTIMEDIA_QLIST_QSIZE_IDX                         = 7, // QList<QSize>
+    SBK_QTMULTIMEDIA_QLIST_QCAMERAFORMAT_IDX                 = 8, // QList<QCameraFormat>
+    SBK_QTMULTIMEDIA_QLIST_QAUDIOFORMAT_SAMPLEFORMAT_IDX     = 9, // QList<QAudioFormat::SampleFormat>
+    SBK_QTMULTIMEDIA_QLIST_QOBJECTPTR_IDX                    = 10, // QList<QObject*>
+    SBK_QTMULTIMEDIA_QLIST_QBYTEARRAY_IDX                    = 11, // QList<QByteArray>
+    SBK_QTMULTIMEDIA_QLIST_QAUDIODEVICE_IDX                  = 12, // QList<QAudioDevice>
+    SBK_QTMULTIMEDIA_QLIST_QCAMERADEVICE_IDX                 = 13, // QList<QCameraDevice>
+    SBK_QTMULTIMEDIA_QLIST_QIMAGECAPTURE_FILEFORMAT_IDX      = 14, // QList<QImageCapture::FileFormat>
+    SBK_QTMULTIMEDIA_QLIST_QMEDIAMETADATA_IDX                = 15, // QList<QMediaMetaData>
+    SBK_QTMULTIMEDIA_QLIST_QVARIANT_IDX                      = 16, // QList<QVariant>
+    SBK_QTMULTIMEDIA_QLIST_QSTRING_IDX                       = 17, // QList<QString>
+    SBK_QTMULTIMEDIA_QMAP_QSTRING_QVARIANT_IDX               = 18, // QMap<QString,QVariant>
     SBK_QtMultimedia_CONVERTERS_IDX_COUNT                    = 19
 };
 // Macros for type check
 
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-QT_WARNING_PUSH
-QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QAudio::Error >() { return SbkPySide6_QtMultimediaTypes[SBK_QAUDIO_ERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QAudio::State >() { return SbkPySide6_QtMultimediaTypes[SBK_QAUDIO_STATE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QAudio::VolumeScale >() { return SbkPySide6_QtMultimediaTypes[SBK_QAUDIO_VOLUMESCALE_IDX]; }
@@ -262,6 +211,8 @@ template<> inline PyTypeObject *SbkType< ::QMediaRecorder::Error >() { return Sb
 template<> inline PyTypeObject *SbkType< ::QMediaRecorder >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QMEDIARECORDER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QMediaTimeRange >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QMEDIATIMERANGE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QMediaTimeRange::Interval >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QMEDIATIMERANGE_INTERVAL_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QScreenCapture::Error >() { return SbkPySide6_QtMultimediaTypes[SBK_QSCREENCAPTURE_ERROR_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QScreenCapture >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QSCREENCAPTURE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSoundEffect::Loop >() { return SbkPySide6_QtMultimediaTypes[SBK_QSOUNDEFFECT_LOOP_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSoundEffect::Status >() { return SbkPySide6_QtMultimediaTypes[SBK_QSOUNDEFFECT_STATUS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSoundEffect >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QSOUNDEFFECT_IDX]); }
@@ -272,11 +223,14 @@ template<> inline PyTypeObject *SbkType< ::QVideoFrame >() { return reinterpret_
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::PixelFormat >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_PIXELFORMAT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::Direction >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_DIRECTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::YCbCrColorSpace >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_YCBCRCOLORSPACE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::ColorSpace >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_COLORSPACE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::ColorTransfer >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_COLORTRANSFER_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat::ColorRange >() { return SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_COLORRANGE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QVideoFrameFormat >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QVIDEOFRAMEFORMAT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QVideoSink >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtMultimediaTypes[SBK_QVIDEOSINK_IDX]); }
-QT_WARNING_POP
 
 } // namespace Shiboken
 
+QT_WARNING_POP
 #endif // SBK_QTMULTIMEDIA_PYTHON_H
 
