@@ -5,10 +5,10 @@ from textwrap import dedent
 
 # __all__ is also corrected below.
 __all__ = list("Qt" + body for body in
-    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Designer;Xml;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLWidgets;Positioning;NetworkAuth;Nfc;Qml;Quick;Quick3D;QuickControls2;QuickWidgets;RemoteObjects;Scxml;Sensors;SerialPort;StateMachine;Charts;Svg;SvgWidgets;DataVisualization;Bluetooth;UiTools;WebChannel;WebSockets;DBus;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
+    "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;Designer;Xml;Help;Multimedia;MultimediaWidgets;OpenGL;OpenGLWidgets;Positioning;Location;NetworkAuth;Nfc;Qml;Quick;Quick3D;QuickControls2;QuickWidgets;RemoteObjects;Scxml;Sensors;SerialPort;SerialBus;StateMachine;TextToSpeech;Charts;SpatialAudio;Svg;SvgWidgets;DataVisualization;Bluetooth;UiTools;WebChannel;WebSockets;HttpServer;DBus;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
     .split(";"))
-__version__ = "6.3.0"
-__version_info__ = (6, 3, 0, "", "")
+__version__ = "6.5.1.1"
+__version_info__ = (6, 5, 1.1, "", "")
 
 
 def _additional_dll_directories(package_dir):
@@ -68,26 +68,6 @@ def _setupQtDirectories():
               file=sys.stderr)
         raise
 
-    #   Trigger signature initialization.
-    try:
-        # PYSIDE-829: Avoid non-existent attributes in compiled code (Nuitka).
-        # We now use an explicit function instead of touching a signature.
-        _init_pyside_extension()
-    except (AttributeError, NameError):
-        stars = 79 * "*"
-        fname = Shiboken.__file__
-        print(dedent(f'''\
-            {stars}
-            PySide6/__init__.py: The `signature` module was not initialized.
-            This libshiboken module was loaded from
-
-            "{fname}".
-
-            Please make sure that this is the real Shiboken binary and not just a folder.
-            {stars}
-            '''), file=sys.stderr)
-        raise
-
     if sys.platform == 'win32':
         # PATH has to contain the package directory, otherwise plugins
         # won't be able to find their required Qt libraries (e.g. the
@@ -123,7 +103,8 @@ def _find_all_qt_modules():
     location = Path(__file__).resolve().parent
 
     # Note: We should _not_ call this function while still building, but use the existing value!
-    in_build = location.parents[2].name == "build"
+    in_build = Path("/build/pyside6/src/build") in location.parents
+
     if in_build:
         return __all__
 
